@@ -1,6 +1,6 @@
 /*
  *  Queue load balancing system
- *  $Revision: 1.8 $
+ *  $Revision: 1.9 $
  *
  *  Copyright (C) 1998-2000 W. G. Krebs
  *
@@ -33,7 +33,7 @@
 
 #define SPOOLDIR QUEUEDIR
 
-#define sock_error(socket, format) write(socket, format, strlen(format)); 
+#define sock_error(socket, format) write(socket, format, strlen(format));
 
 extern char *getenv(const char *);
 /*extern char *index();*/
@@ -111,8 +111,8 @@ void error (char *s);
 void cleanup(void);
 
 /*WGK: The following is for do_queue part of the system.*/
-void 
-send_signal(int signal) 
+void
+send_signal(int signal)
 {
   char sig;
   /*Sig pipe means queued has died.*/
@@ -270,8 +270,8 @@ main(int argc, char **argv, char **arge)
       }
       prefhost = strdup(canonicalhost(optarg));
       if(!validhost(prefhost, 0)) {
-	fprintf(stderr, 
-		"Queue: invalid queue hostname: %s\n", prefhost); 
+	fprintf(stderr,
+		"Queue: invalid queue hostname: %s\n", prefhost);
 	exit(1);
       }
       onlyhost = prefhost;
@@ -284,7 +284,7 @@ main(int argc, char **argv, char **arge)
       }
       prefhost = strdup(canonicalhost(optarg));
       if(!validhost(prefhost, 0)) {
-	fprintf(stderr, "Queue: invalid queue hostname: %s\n", prefhost); 
+	fprintf(stderr, "Queue: invalid queue hostname: %s\n", prefhost);
 	exit(1);
       }
       prefhost=prefhost;
@@ -341,9 +341,9 @@ main(int argc, char **argv, char **arge)
 	fprintf(stderr, "Bug reports to bug-queue@gnu.org.\n");
 	exit(0);
       }
-		    
+		
     default:
-      if(strcmp(invoke, "qsh")==0) Qshusage(); 
+      if(strcmp(invoke, "qsh")==0) Qshusage();
       Usage();
     }
 
@@ -508,7 +508,7 @@ main(int argc, char **argv, char **arge)
 	  }
 	  perror("queue: bind");
 	  exit(2);
-	}               
+	}
 
       }
     }
@@ -565,7 +565,7 @@ main(int argc, char **argv, char **arge)
 
     {
       int minusone = -1;
-      fwrite(&minusone, sizeof(int), 1, queue);
+      netfwrite(&minusone, sizeof(int), 1, queue);
     }
 
     /*Per draft protocol, start of job control file is the version
@@ -576,7 +576,7 @@ main(int argc, char **argv, char **arge)
     /*UID, userid, mailuserid, and jobname come first because of
       jobinfo(). */
 
-    fwrite(&uid, sizeof(int), 1, queue);
+    netfwrite(&uid, sizeof(int), 1, queue);
     fputs(userid, queue);
     fputc('\0', queue);
     fputs(mailuserid, queue);
@@ -586,7 +586,7 @@ main(int argc, char **argv, char **arge)
     if (onlyhost && *onlyhost) {fputs(onlyhost, queue);}
     else {fputs(" ", queue);}
     fputc('\0', queue);
-    fwrite(&donthang, sizeof(int), 1, queue);
+    netfwrite(&donthang, sizeof(int), 1, queue);
 
     /*WGK Set the cookie here. We basically just combine the tfname,
       which contains the time, with a psuedo-random number. It's not
@@ -616,18 +616,19 @@ main(int argc, char **argv, char **arge)
     if(!(myhost = gethostbyname(buf))) {
       /*WGK 98/12/19 prevent seg fault if DNS goes down.*/
       setuid(getuid()); /*Drop privileges*/
-      fprintf(stderr, 
+      fprintf(stderr,
 	      "queue: gethostbyname failed; can't get my IP address.\n");
       herror("queue");
       fprintf(stderr, "queue: DNS is probably down and resolv+ isn't configured to get the IP address from /etc/hosts.\n");
       exit(2);
     }
+    /* EJD -- 8/14/2000 -- host address is already network order - Don't swap */
     fwrite(myhost->h_addr, sizeof(address1.sin_addr), 1, queue);
-    fwrite(&miport, sizeof(int), 1, queue);
+    netfwrite(&miport, sizeof(int), 1, queue);
 
     {int temp;
     temp = argc - optind;
-    fwrite(&temp, sizeof(int), 1, queue);
+    netfwrite(&temp, sizeof(int), 1, queue);
     for(i=optind;i<argc;++i) {
       fputs(argv[i], queue);
       fputc(0, queue);
@@ -649,12 +650,12 @@ main(int argc, char **argv, char **arge)
       perror("getgroups2");
       exit(2);
     }
-    fwrite(&aid, sizeof(int), 1, queue);
-    fwrite(&euid, sizeof(int), 1, queue);
-    fwrite(&egid, sizeof(int), 1, queue);
-    fwrite(&gid, sizeof(int), 1, queue);
-    fwrite(&ngroups, sizeof(int), 1, queue);
-    fwrite(gidset, sizeof(gid_t), ngroups, queue);
+    netfwrite(&aid, sizeof(int), 1, queue);
+    netfwrite(&euid, sizeof(int), 1, queue);
+    netfwrite(&egid, sizeof(int), 1, queue);
+    netfwrite(&gid, sizeof(int), 1, queue);
+    netfwrite(&ngroups, sizeof(int), 1, queue);
+    netfwrite(gidset, sizeof(gid_t), ngroups, queue);
     free(gidset);
     {
       int temp;
@@ -664,11 +665,11 @@ main(int argc, char **argv, char **arge)
 #endif
       ttyoutput = 0;
       if (ttyinput) ttyinput = (char) isatty(0);
-      fwrite(&ttyinput, sizeof(ttyinput), 1, queue);
+      netfwrite(&ttyinput, sizeof(ttyinput), 1, queue);
       if (ttyinput) ttyoutput= (char) isatty(1);
-      fwrite(&ttyoutput, sizeof(ttyoutput), 1, queue);
+      netfwrite(&ttyoutput, sizeof(ttyoutput), 1, queue);
       if (ttyoutput) ttyerror= (char) isatty(2);
-      fwrite(&ttyerror, sizeof(ttyoutput), 1, queue);
+      netfwrite(&ttyerror, sizeof(ttyoutput), 1, queue);
       if((ttyinput)||(ttyoutput)) {
 	if((!ttyinput)&&(ttyinput)) temp = 1;
 	else temp = 0;
@@ -679,9 +680,9 @@ main(int argc, char **argv, char **arge)
 #endif
 
       }
-      fwrite(&globalterm, sizeof(globalterm), 1, queue);
+      netfwrite(&globalterm, sizeof(globalterm), 1, queue);
 #ifdef TIOCSWINSZ
-      fwrite(&ws, sizeof(ws), 1, queue);
+      netfwrite(&ws, sizeof(ws), 1, queue);
 #endif
     }
     while ((cur = *arge)!=0) {
@@ -691,12 +692,12 @@ main(int argc, char **argv, char **arge)
     fputc(0, queue);
     mask=umask(0);
     umask(mask);
-    fwrite(&mask, sizeof(mode_t), 1, queue);
+    netfwrite(&mask, sizeof(mode_t), 1, queue);
     prio = getpriority(PRIO_PROCESS, 0);
-    fwrite(&prio, sizeof(int), 1, queue);
+    netfwrite(&prio, sizeof(int), 1, queue);
     for(i=0;i<8;++i) {
       getrlimit(i, &myrlimit);
-      fwrite(&myrlimit, sizeof(struct rlimit), 1, queue);
+      netfwrite(&myrlimit, sizeof(struct rlimit), 1, queue);
     }
 
     fflush(queue);
@@ -770,7 +771,7 @@ main(int argc, char **argv, char **arge)
 	prot = IPPROTO_IP;
 
       optionsize = sizeof(optionbuf);
-      if (getsockopt(newsocket, prot, IP_OPTIONS, 
+      if (getsockopt(newsocket, prot, IP_OPTIONS,
 		     (char *) optionbuf, &optionsize) == 0
 	  && optionsize != 0) {
 	/* We probably don't need this since we're checking to make
@@ -822,7 +823,7 @@ Have your administrator fix identd problems on your cluster, OR recompile withou
       exit(2);
     }
 #endif /*HAVE_IDENTD*/
-#endif /*NO_ROOT*/ 
+#endif /*NO_ROOT*/
 
 	 /*#if defined(HAVE_IDENTD) || !defined(NO_ROOT) || defined(NO_SECURITY)*/
 	 /*WGK 1998/12/25 get speed back if crypt() isn't needed because portsare privileged or verifiable.*/
@@ -868,7 +869,7 @@ DFPRINTF3(stderr,"cnounce %s\n",cnounce);
     randomstr(&nounce[0]);
     DFPRINTF3(stderr,"nounce %s\n",nounce);
     write(newsocket, &nounce, strlen(nounce)+1);
-    
+
     strcpy(bigcookie,nounce);
     strcat(bigcookie,cookie);
     strcat(bigcookie,cnounce);
@@ -904,7 +905,7 @@ DFPRINTF3(stderr,"cnounce %s\n",cnounce);
       write(newsocket, &cnounce, strlen(cnounce)+1);
       DFPRINTF3(stderr,"wrote cnounce %s\n",cnounce);
       /*Read nounce, as compliant with draft protocol. WGK 2000/07/20*/
- 
+
       alarm(5);
     k = 0;
     do {
@@ -927,7 +928,7 @@ DFPRINTF3(stderr,"cnounce %s\n",cnounce);
 flag = 0;
       write(newsocket, &randomcookie[0], strlen(randomcookie)+1);
        /*Wait for the OK byte from other side indicating authentication has been successful.*/
-  
+
       alarm(10);
       read(newsocket, &c, 1);
       alarm(0);
@@ -995,7 +996,7 @@ flag = 0;
       perror("queue: problem getting second socket");
       exit(1);
     }
- 
+
 #endif /*NO_ROOT*/
 
     address1.sin_port = htons((u_short) secondport);
@@ -1023,7 +1024,7 @@ flag = 0;
       for ( ; ; hostp->h_addr_list++) {
 	if (bcmp(hostp->h_addr_list[0], (caddr_t) &address1.sin_addr, sizeof(address1.sin_addr)) == 0)
 	  break; /* reverse lookup test passed.*/
-	    
+	
 	if (hostp->h_addr_list[0] == NULL) {
 	  fprintf(stderr,
 		  "Host addr %s not listed for host %s", inet_ntoa(address1.sin_addr), hostp->h_name);
@@ -1035,9 +1036,9 @@ flag = 0;
       strncpy(remotehost, hostp->h_name, sizeof(remotehost) - 1);
       remotehost[sizeof(remotehost) - 1] = 0;
       hostname = canonicalhost(remotehost);
-    } 
+    }
     else
-      hostname = "unresolved"; 
+      hostname = "unresolved";
     /*Our DNS must be down and this will probably fail.*/
 
     if(!validhost(hostname, newsocket)) exit(1);
@@ -1084,7 +1085,7 @@ flag = 0;
     fdsocket3 = dup(fdsocket2);
 
     /*WGK: OOB messages will contain information about wait signals
-      from the remote job.  
+      from the remote job.
       Non-OOB is stderr.*/
 
     setsockopt(fdsocket3, SOL_SOCKET, SO_OOBINLINE, &one, sizeof(one));
@@ -1125,7 +1126,7 @@ flag = 0;
       /*Block all other signals so that signals are delivered in order
         received.*/
       mysignal.sv_mask= ~0L;
-      for(i=0;i<64;++i) sigvector(i, &mysignal, NULL);    
+      for(i=0;i<64;++i) sigvector(i, &mysignal, NULL);
 #else  /*GNU/Linux*/
       struct sigaction mysignal;
       mysignal.sa_handler = send_signal;
@@ -1151,10 +1152,10 @@ flag = 0;
 	uses the other 64 signals that are partially defined in
 	<sigset.h>*/
       mysignal.sa_flags = SA_RESTART;
-      for(i=0;i<64;++i) sigaction(i, &mysignal, NULL);    
+      for(i=0;i<64;++i) sigaction(i, &mysignal, NULL);
 #endif
       sigsetmask(0L);
-    }     
+    }
 
 #ifdef ENABLE_CHECKPOINT
     if(checkpointed) {
@@ -1188,7 +1189,7 @@ flag = 0;
 	  this read get interrupted by signals at all costs!.*/
 	long oldmask;
 	oldmask=sigsetmask(~0L);
-	if ((cint=read(newsocket, buf, sizeof(buf))) <= 0) { 
+	if ((cint=read(newsocket, buf, sizeof(buf))) <= 0) {
 
 
 	  /*  if (errno!= EINTR) FD_CLR(newsocket, &readf);*/
@@ -1284,11 +1285,11 @@ flag = 0;
 
 	      /*Again, this is thought to be the most portable
 		version:*/
-  
+
 	      *((unsigned long int*) &mysignal.sa_mask) = ~0L;
 
 
-  
+
 	      mysignal.sa_flags = SA_RESTART;
 #endif
 
@@ -1342,7 +1343,7 @@ flag = 0;
 	/* Turn off OOB inline mode so as not to read it in now.*/
 	setsockopt(fdsocket3, SOL_SOCKET, SO_OOBINLINE, &zero, sizeof(one));
 	if ((cint=read(fdsocket2, buf, sizeof(buf))) >0 ){
-	  write(2, buf, cint);  
+	  write(2, buf, cint);
 	}
 	else {FD_CLR(fdsocket2, &readf);}
 	/* Turn OOB inline back on so that select() works.*/
@@ -1379,7 +1380,7 @@ cleanup(void)
 
 /*Read a string from the socket making sure that it fits into our buffer.*/
 void
-getstr(int socket, char *buffer, 
+getstr(int socket, char *buffer,
        int size, /* size of the char array */
        char *errm /* what to say if string is too long.*/)
 {
@@ -1503,7 +1504,7 @@ syserror(char *s)
     syslog(LOG_ALERT, "queue: %s", s);
 }
 
-int 
+int
 validhost(char *hostcpy, int socket)
 {
   char buf[MAXHOSTNAMELEN + 1];
@@ -1511,7 +1512,7 @@ validhost(char *hostcpy, int socket)
   int flag = 1;
   char *hostname = buf;
 
-  hostname = strncpy(hostname, hostcpy, MAXHOSTNAMELEN); 
+  hostname = strncpy(hostname, hostcpy, MAXHOSTNAMELEN);
   /*Unfortunately, the static area from gethostbynames is completely
     unstable on some platforms and will not survive a call to stat(),
     which is used in readhosts.*/
@@ -1532,8 +1533,8 @@ validhost(char *hostcpy, int socket)
     fprintf(stderr, "Authorized hosts in %s are:\n", QHOSTSFILE);
     for(i=0;i<NHosts;++i) fprintf(stderr, "%s\n", Hosts[i].host);
     fprintf(stderr, "\n");
-    if(socket) 
-      sock_error(socket, 
+    if(socket)
+      sock_error(socket,
 		 "This server is not in QHOSTSFILE as a valid server host.\n");
     return(0);
   }
